@@ -1,9 +1,7 @@
 from collections import defaultdict
 
 import matplotlib.pyplot as plt
-import seaborn as sns
-
-sns.set(style="dark")
+plt.style.use("seaborn-darkgrid")
 
 
 class ExperimentPlotter:
@@ -125,7 +123,7 @@ class ExperimentPlotter:
         title = f"{x_axis}={x}" if x_axis else ""
         title += ", " if x_axis and y_axis else ""
         title += f"{y_axis}={y}" if y_axis else ""
-        ax.set_title(title)
+        ax.set_title(title, fontweight="bold")
 
         i, j, max_i, _ = kwargs["axis_"]
         if i == max_i-1:
